/************************************************************************/
/************        IRFD - CELL BASED		*************************/
/************************************************************************/
/*									*/
/* Module Name:	 	CB_IRFD                                   	*/
/* File Name:	 	cb_irfd.v                           		*/
/* Function:		Behavioral model of IRF's			*/
/*									*/
/* Language: 		Verilog						*/
/*									*/
/* Creator:		Andrew Chang  					*/
/*									*/
/* History:								*/
/*		960302	achang	Created (derived from irfd.v)		*/
/*				Composed of 2bit versions of RFD_CELL	*/
/*				IRFD_SLICE5, IRFD_SLICE6 		*/
/*		960328  achang  Resync'd number of registers to match   */
/*				implementation  ie i2-i6 x6, i7-i15 x5	*/
/*		970302  achang  Deleted unused modules/general cleanup	*/
/*		971207  achang  Extended width to 64 bits		*/
/*									*/
/* Copyright (C) 1994, 1995, 1996, 1997, 1998 Andrew Chang              */
/*                                                                      */
/* Massachusetts Institute of Technology                                */
/* Concurrent VLSI Architecture Group                                   */
/* All rights reserved                                                  */
/*									*/
/************************************************************************/

/*


 IRF  (14 per Hthread: Vthread  0-4)
 IRF  (5 per Hthread: Vthread  5)

 Note: order 	[MSZ,PTR] ie.  MSZ = MSB
			       PTR = LSB	


*/

// MINI DATAPATH


`include "/home/mm/rtl/map/clst/clst.vhout"
`include "/home/mm/rtl/lib/stdlib/primitives.v"


/*==>>*/
module CB_IRFD_SLICE6				// 4R/3W ports (send =>  5R/2W)
	( 
	  iwrx, cwrx,				// Write Ports
	  iwb_d, mwb_d, csw_d,			//	 Data
	  wbrx,					// Local Write thread select

	  rdrx,					// Read thread select  		  	



	  dout

	);

	input iwrx;					// IU, MU writeback
	input [`VTHRDS-1:0] cwrx;			// CSW (1 per reg)

	input [`WORD_W-1:0] iwb_d;			// Bidirectional due to SEND 

	input [`WORD_W-1:0] mwb_d, csw_d;		// IU, FU, CSW Write data
	input [`VTHRDS-1:0] wbrx;			// WB thread select

	input  [`VTHRDS-1:0] rdrx;			// RD thread select

		
	inout  [`WORD_W-1:0] dout;	// IU s1, s2 values

	wire  [`WORD_W-1:0] wb_d;
	wire  [`WORD_W-1:0] rdD;

/*<<==*/

	assign #`TGPD					// WRITE
	    dout = rdD,
	    wb_d  = iwrx ? iwb_d : mwb_d;

// Instantiations

CB_FRFD_CELL v0reg (wbrx[0], cwrx[0], wb_d, csw_d, rdrx[0], rdD);
CB_FRFD_CELL v1reg (wbrx[1], cwrx[1], wb_d, csw_d, rdrx[1], rdD);
CB_FRFD_CELL v2reg (wbrx[2], cwrx[2], wb_d, csw_d, rdrx[2], rdD);
CB_FRFD_CELL v3reg (wbrx[3], cwrx[3], wb_d, csw_d, rdrx[3], rdD);
CB_FRFD_CELL v4reg (wbrx[4], cwrx[4], wb_d, csw_d, rdrx[4], rdD);
CB_FRFD_CELL v5reg (wbrx[5], cwrx[5], wb_d, csw_d, rdrx[5], rdD);

endmodule




/*==>>*/
module CB_IRFD_SLICE5				// 4R/3W ports (send =>  5R/2W)
	( 
	  iwrx, cwrx,				// Write Ports
	  iwb_d, mwb_d, csw_d,			//	 Data
	  wbrx,					// Local Write thread select

	  rdrx,					// Read thread select  		  	

	 dout
	);

	input iwrx;					// IU, MU writeback
	input [`VTHRDS-2:0] cwrx;			// CSW (1 per reg)

	input [`WORD_W-1:0] iwb_d;			// Bidirectional due to SEND 

	input [`WORD_W-1:0] mwb_d, csw_d;		// IU, FU, CSW Write data
	input [`VTHRDS-2:0] wbrx;			// WB thread select

	input  [`VTHRDS-2:0] rdrx;			// RD thread select

		
	inout  [`WORD_W-1:0]  dout;	// MU s1, s2 values

	wire  [`WORD_W-1:0] wb_d;
	wire  [`WORD_W-1:0] rdD;

/*<<==*/

	assign #`TGPD					// WRITE
	    dout = rdD,
	    wb_d  = iwrx ? iwb_d : mwb_d;

// Instantiations

CB_FRFD_CELL v0reg (wbrx[0], cwrx[0], wb_d, csw_d, rdrx[0], rdD);
CB_FRFD_CELL v1reg (wbrx[1], cwrx[1], wb_d, csw_d, rdrx[1], rdD);
CB_FRFD_CELL v2reg (wbrx[2], cwrx[2], wb_d, csw_d, rdrx[2], rdD);
CB_FRFD_CELL v3reg (wbrx[3], cwrx[3], wb_d, csw_d, rdrx[3], rdD);
CB_FRFD_CELL v4reg (wbrx[4], cwrx[4], wb_d, csw_d, rdrx[4], rdD);

endmodule






/*==>>*/
module CB_IRFD					// 4R/3W ports (send =>  5R/2W)
	( 
	  iwrx, 
	  cwr2,	 cwr3, cwr4, cwr5,		// Write Ports
	  cwr6,	 cwr7, cwr8, cwr9,		// 
	  cwr10, cwr11, cwr12, cwr13,		// 
	  cwr14, cwr15, 			// 

	  iwb_d, mwb_d, csw_d,			//	 Data

	  wbr2,	 wbr3, wbr4, wbr5,		// Local WB thread select 
	  wbr6,	 wbr7, wbr8, wbr9,		// 
	  wbr10, wbr11, wbr12, wbr13,		// 
	  wbr14, wbr15, 

	 sndrx,

	  ir1rx, ir2rx,				// Read Ports
	  mr1rx,mr2rx,
						
	  rdr2,	 rdr3, rdr4, rdr5,		// Read thread select  	
	  rdr6,	 rdr7, rdr8, rdr9,		// 
	  rdr10, rdr11, rdr12, rdr13,		// 
	  rdr14, rdr15, 


	  ir1D, ir2D,				// Read Data
	  mr1D, mr2D,
	  dout
	);

	input  [`IREGS-1:2] iwrx;			// IU, MU writeback
                                                        // register select

	input  [`IREGS-1:2] sndrx;			// which reg to send


	input [`VTHRDS-1:0] cwr2,cwr3,cwr4,cwr5;	// CSW (1 per reg id)
	input [`VTHRDS-1:0] cwr6;
	input [`VTHRDS-2:0] cwr7, cwr8,cwr9;		// 
	input [`VTHRDS-2:0] cwr10,cwr11,cwr12,cwr13;	// 
	input [`VTHRDS-2:0] cwr14,cwr15;		// 

	input [`WORD_W-1:0] iwb_d;			// Bidirectional due to SEND 

	input [`WORD_W-1:0] mwb_d, csw_d;		// IU, MU, CSW WR data

	input [`VTHRDS-1:0] wbr2,wbr3,wbr4,wbr5;	// WB thread select
	input [`VTHRDS-1:0] wbr6;                  	// 1 per reg id
	input [`VTHRDS-2:0] wbr7, wbr8,wbr9;	
	input [`VTHRDS-2:0] wbr10,wbr11,wbr12,wbr13;	// 
	input [`VTHRDS-2:0] wbr14,wbr15;		// 

	input [`IREGS-1:2] ir1rx, ir2rx;		// Read reg enable
							//  for IU src1, src2 

	input [`IREGS-1:2] mr1rx, mr2rx;		// Read reg enable for 
							// MU src1, src2

	input [`VTHRDS-1:0] rdr2,rdr3,rdr4,rdr5;	// RD thread select
	input [`VTHRDS-1:0] rdr6;
	input [`VTHRDS-2:0] rdr7, rdr8,rdr9;	        // 1 per reg id
	input [`VTHRDS-2:0] rdr10,rdr11,rdr12,rdr13;	// 
	input [`VTHRDS-2:0] rdr14,rdr15;		//


	output  [`WORD_W-1:0] ir1D, ir2D;	// IU s1, s2 values
	output  [`WORD_W-1:0]  mr1D, mr2D;	// MU s1, s2 values
	output  [`WORD_W-1:0]  dout;	

/*<<==*/

  wire [`WORD_W-1:0]  dout2, dout3, dout4, dout5, dout6, dout7, dout8;
  wire [`WORD_W-1:0]  dout9, dout10, dout11, dout12, dout13, dout14, dout15; 

  assign #1
      ir1D = ( dout2 & {`WORD_W{ir1rx[2]}} |
	      dout3 & {`WORD_W{ir1rx[3]}} |
	      dout4 & {`WORD_W{ir1rx[4]}} |
	      dout5 & {`WORD_W{ir1rx[5]}} |
	      dout6 & {`WORD_W{ir1rx[6]}} |
	      dout7 & {`WORD_W{ir1rx[7]}} |
	      dout8 & {`WORD_W{ir1rx[8]}} |
	      dout9 & {`WORD_W{ir1rx[9]}} |
	      dout10 & {`WORD_W{ir1rx[10]}} |
	      dout11 & {`WORD_W{ir1rx[11]}} |
	      dout12 & {`WORD_W{ir1rx[12]}} |
	      dout13 & {`WORD_W{ir1rx[13]}} |
	      dout14 & {`WORD_W{ir1rx[14]}} |
	      dout15 & {`WORD_W{ir1rx[15]}} ),
      ir2D = ( dout2 & {`WORD_W{ir2rx[2]}} |
	      dout3 & {`WORD_W{ir2rx[3]}} |
	      dout4 & {`WORD_W{ir2rx[4]}} |
	      dout5 & {`WORD_W{ir2rx[5]}} |
	      dout6 & {`WORD_W{ir2rx[6]}} |
	      dout7 & {`WORD_W{ir2rx[7]}} |
	      dout8 & {`WORD_W{ir2rx[8]}} |
	      dout9 & {`WORD_W{ir2rx[9]}} |
	      dout10 & {`WORD_W{ir2rx[10]}} |
	      dout11 & {`WORD_W{ir2rx[11]}} |
	      dout12 & {`WORD_W{ir2rx[12]}} |
	      dout13 & {`WORD_W{ir2rx[13]}} |
	      dout14 & {`WORD_W{ir2rx[14]}} |
	      dout15 & {`WORD_W{ir2rx[15]}} ),
      mr1D = ( dout2 & {`WORD_W{mr1rx[2]}} |
	      dout3 & {`WORD_W{mr1rx[3]}} |
	      dout4 & {`WORD_W{mr1rx[4]}} |
	      dout5 & {`WORD_W{mr1rx[5]}} |
	      dout6 & {`WORD_W{mr1rx[6]}} |
	      dout7 & {`WORD_W{mr1rx[7]}} |
	      dout8 & {`WORD_W{mr1rx[8]}} |
	      dout9 & {`WORD_W{mr1rx[9]}} |
	      dout10 & {`WORD_W{mr1rx[10]}} |
	      dout11 & {`WORD_W{mr1rx[11]}} |
	      dout12 & {`WORD_W{mr1rx[12]}} |
	      dout13 & {`WORD_W{mr1rx[13]}} |
	      dout14 & {`WORD_W{mr1rx[14]}} |
	      dout15 & {`WORD_W{mr1rx[15]}} ),
      mr2D = ( dout2 & {`WORD_W{mr2rx[2]}} |
	      dout3 & {`WORD_W{mr2rx[3]}} |
	      dout4 & {`WORD_W{mr2rx[4]}} |
	      dout5 & {`WORD_W{mr2rx[5]}} |
	      dout6 & {`WORD_W{mr2rx[6]}} |
	      dout7 & {`WORD_W{mr2rx[7]}} |
	      dout8 & {`WORD_W{mr2rx[8]}} |
	      dout9 & {`WORD_W{mr2rx[9]}} |
	      dout10 & {`WORD_W{mr2rx[10]}} |
	      dout11 & {`WORD_W{mr2rx[11]}} |
	      dout12 & {`WORD_W{mr2rx[12]}} |
	      dout13 & {`WORD_W{mr2rx[13]}} |
	      dout14 & {`WORD_W{mr2rx[14]}} |
	      dout15 & {`WORD_W{mr2rx[15]}} ),
      dout = ( dout2 & {`WORD_W{sndrx[2]}} |
	      dout3 & {`WORD_W{sndrx[3]}} |
	      dout4 & {`WORD_W{sndrx[4]}} |
	      dout5 & {`WORD_W{sndrx[5]}} |
	      dout6 & {`WORD_W{sndrx[6]}} |
	      dout7 & {`WORD_W{sndrx[7]}} |
	      dout8 & {`WORD_W{sndrx[8]}} |
	      dout9 & {`WORD_W{sndrx[9]}} |
	      dout10 & {`WORD_W{sndrx[10]}} |
	      dout11 & {`WORD_W{sndrx[11]}} |
	      dout12 & {`WORD_W{sndrx[12]}} |
	      dout13 & {`WORD_W{sndrx[13]}} |
	      dout14 & {`WORD_W{sndrx[14]}} |
	      dout15 & {`WORD_W{sndrx[15]}} );


// Instantiations


CB_IRFD_SLICE6 reg2
( iwrx[2], cwr2, iwb_d, mwb_d, csw_d, wbr2,
 rdr2,
 dout2 );


CB_IRFD_SLICE6 reg3
( iwrx[3], cwr3, iwb_d, mwb_d, csw_d, wbr3, 
 rdr3,
  dout3 );


CB_IRFD_SLICE6 reg4
( iwrx[4], cwr4, iwb_d, mwb_d, csw_d, wbr4, 
 rdr4,
  dout4 );


CB_IRFD_SLICE6 reg5
( iwrx[5], cwr5, iwb_d, mwb_d, csw_d, wbr5, 
 rdr5,
  dout5 );


CB_IRFD_SLICE6 reg6
( iwrx[6], cwr6, iwb_d, mwb_d, csw_d, wbr6, 
 rdr6,
  dout6 );


CB_IRFD_SLICE5 reg7
( iwrx[7], cwr7, iwb_d, mwb_d, csw_d, wbr7, 
 rdr7,
  dout7 );


CB_IRFD_SLICE5 reg8
( iwrx[8], cwr8, iwb_d, mwb_d, csw_d, wbr8, 
 rdr8,
  dout8 );


CB_IRFD_SLICE5 reg9
( iwrx[9], cwr9, iwb_d, mwb_d, csw_d, wbr9, 
 rdr9,
  dout9 );


CB_IRFD_SLICE5 reg10
( iwrx[10],  cwr10, iwb_d, mwb_d, csw_d, wbr10, 
 rdr10,
  dout10 );


CB_IRFD_SLICE5 reg11
( iwrx[11],  cwr11, iwb_d, mwb_d, csw_d, wbr11, 
 rdr11,
  dout11 );


CB_IRFD_SLICE5 reg12
( iwrx[12],  cwr12, iwb_d, mwb_d, csw_d, wbr12, 
 rdr12,
  dout12 );


CB_IRFD_SLICE5 reg13
( iwrx[13],  cwr13, iwb_d, mwb_d, csw_d, wbr13, 
 rdr13,
  dout13 );



CB_IRFD_SLICE5 reg14
( iwrx[14],  cwr14, iwb_d, mwb_d, csw_d, wbr14, 
 rdr14,
  dout14 );



CB_IRFD_SLICE5 reg15
( iwrx[15],  cwr15, iwb_d, mwb_d, csw_d, wbr15, 
 rdr15,
  dout15 );




endmodule



/*==>>*/
  module CB_FRFD_CELL                      // 1R/2W ports
    (
     wbrx, cwrx,                           // Write Ports
     wb_d, csw_d,                          //       Data
     
     rdrx,                                 // Read thread select
     
     rdD
     // to emulate SEND reading
     );
    
    input wbrx;                             // Writeback regID & Vthrd match
    input cwrx;                             // CSW write  regID & Vthrd match
    input [`WORD_W-1:0] wb_d, csw_d;
    input rdrx;                             // Read regID & Vthrd Match
    
    inout [`WORD_W-1:0] rdD;
/*<<==*/
 


 FRFD_CELL_MSZPTR_BASE w0bit (wb_d[0], wbrx, csw_d[0], cwrx, rdrx, rdD[0]);
 FRFD_CELL_MSZPTR_BASE w1bit (wb_d[1], wbrx, csw_d[1], cwrx, rdrx, rdD[1]);
 FRFD_CELL_MSZPTR_BASE w2bit (wb_d[2], wbrx, csw_d[2], cwrx, rdrx, rdD[2]);
 FRFD_CELL_MSZPTR_BASE w3bit (wb_d[3], wbrx, csw_d[3], cwrx, rdrx, rdD[3]);
 FRFD_CELL_MSZPTR_BASE w4bit (wb_d[4], wbrx, csw_d[4], cwrx, rdrx, rdD[4]);
 FRFD_CELL_MSZPTR_BASE w5bit (wb_d[5], wbrx, csw_d[5], cwrx, rdrx, rdD[5]);
 FRFD_CELL_MSZPTR_BASE w6bit (wb_d[6], wbrx, csw_d[6], cwrx, rdrx, rdD[6]);
 FRFD_CELL_MSZPTR_BASE w7bit (wb_d[7], wbrx, csw_d[7], cwrx, rdrx, rdD[7]);
 FRFD_CELL_MSZPTR_BASE w8bit (wb_d[8], wbrx, csw_d[8], cwrx, rdrx, rdD[8]);
 FRFD_CELL_MSZPTR_BASE w9bit (wb_d[9], wbrx, csw_d[9], cwrx, rdrx, rdD[9]);
//
 FRFD_CELL_MSZPTR_BASE w10bit (wb_d[10], wbrx, csw_d[10], cwrx, rdrx, rdD[10]);
 FRFD_CELL_MSZPTR_BASE w11bit (wb_d[11], wbrx, csw_d[11], cwrx, rdrx, rdD[11]);
 FRFD_CELL_MSZPTR_BASE w12bit (wb_d[12], wbrx, csw_d[12], cwrx, rdrx, rdD[12]);
 FRFD_CELL_MSZPTR_BASE w13bit (wb_d[13], wbrx, csw_d[13], cwrx, rdrx, rdD[13]);
 FRFD_CELL_MSZPTR_BASE w14bit (wb_d[14], wbrx, csw_d[14], cwrx, rdrx, rdD[14]);
 FRFD_CELL_MSZPTR_BASE w15bit (wb_d[15], wbrx, csw_d[15], cwrx, rdrx, rdD[15]);
 FRFD_CELL_MSZPTR_BASE w16bit (wb_d[16], wbrx, csw_d[16], cwrx, rdrx, rdD[16]);
 FRFD_CELL_MSZPTR_BASE w17bit (wb_d[17], wbrx, csw_d[17], cwrx, rdrx, rdD[17]);
 FRFD_CELL_MSZPTR_BASE w18bit (wb_d[18], wbrx, csw_d[18], cwrx, rdrx, rdD[18]);
 FRFD_CELL_MSZPTR_BASE w19bit (wb_d[19], wbrx, csw_d[19], cwrx, rdrx, rdD[19]);
//
 FRFD_CELL_MSZPTR_BASE w20bit (wb_d[20], wbrx, csw_d[20], cwrx, rdrx, rdD[20]);
 FRFD_CELL_MSZPTR_BASE w21bit (wb_d[21], wbrx, csw_d[21], cwrx, rdrx, rdD[21]);
 FRFD_CELL_MSZPTR_BASE w22bit (wb_d[22], wbrx, csw_d[22], cwrx, rdrx, rdD[22]);
 FRFD_CELL_MSZPTR_BASE w23bit (wb_d[23], wbrx, csw_d[23], cwrx, rdrx, rdD[23]);
 FRFD_CELL_MSZPTR_BASE w24bit (wb_d[24], wbrx, csw_d[24], cwrx, rdrx, rdD[24]);
 FRFD_CELL_MSZPTR_BASE w25bit (wb_d[25], wbrx, csw_d[25], cwrx, rdrx, rdD[25]);
 FRFD_CELL_MSZPTR_BASE w26bit (wb_d[26], wbrx, csw_d[26], cwrx, rdrx, rdD[26]);
 FRFD_CELL_MSZPTR_BASE w27bit (wb_d[27], wbrx, csw_d[27], cwrx, rdrx, rdD[27]);
 FRFD_CELL_MSZPTR_BASE w28bit (wb_d[28], wbrx, csw_d[28], cwrx, rdrx, rdD[28]);
 FRFD_CELL_MSZPTR_BASE w29bit (wb_d[29], wbrx, csw_d[29], cwrx, rdrx, rdD[29]);
//
 FRFD_CELL_MSZPTR_BASE w30bit (wb_d[30], wbrx, csw_d[30], cwrx, rdrx, rdD[30]);
 FRFD_CELL_MSZPTR_BASE w31bit (wb_d[31], wbrx, csw_d[31], cwrx, rdrx, rdD[31]);
 FRFD_CELL_MSZPTR_BASE w32bit (wb_d[32], wbrx, csw_d[32], cwrx, rdrx, rdD[32]);
 FRFD_CELL_MSZPTR_BASE w33bit (wb_d[33], wbrx, csw_d[33], cwrx, rdrx, rdD[33]);
 FRFD_CELL_MSZPTR_BASE w34bit (wb_d[34], wbrx, csw_d[34], cwrx, rdrx, rdD[34]);
 FRFD_CELL_MSZPTR_BASE w35bit (wb_d[35], wbrx, csw_d[35], cwrx, rdrx, rdD[35]);
 FRFD_CELL_MSZPTR_BASE w36bit (wb_d[36], wbrx, csw_d[36], cwrx, rdrx, rdD[36]);
 FRFD_CELL_MSZPTR_BASE w37bit (wb_d[37], wbrx, csw_d[37], cwrx, rdrx, rdD[37]);
 FRFD_CELL_MSZPTR_BASE w38bit (wb_d[38], wbrx, csw_d[38], cwrx, rdrx, rdD[38]);
 FRFD_CELL_MSZPTR_BASE w39bit (wb_d[39], wbrx, csw_d[39], cwrx, rdrx, rdD[39]);
//
 FRFD_CELL_MSZPTR_BASE w40bit (wb_d[40], wbrx, csw_d[40], cwrx, rdrx, rdD[40]);
 FRFD_CELL_MSZPTR_BASE w41bit (wb_d[41], wbrx, csw_d[41], cwrx, rdrx, rdD[41]);
 FRFD_CELL_MSZPTR_BASE w42bit (wb_d[42], wbrx, csw_d[42], cwrx, rdrx, rdD[42]);
 FRFD_CELL_MSZPTR_BASE w43bit (wb_d[43], wbrx, csw_d[43], cwrx, rdrx, rdD[43]);
 FRFD_CELL_MSZPTR_BASE w44bit (wb_d[44], wbrx, csw_d[44], cwrx, rdrx, rdD[44]);
 FRFD_CELL_MSZPTR_BASE w45bit (wb_d[45], wbrx, csw_d[45], cwrx, rdrx, rdD[45]);
 FRFD_CELL_MSZPTR_BASE w46bit (wb_d[46], wbrx, csw_d[46], cwrx, rdrx, rdD[46]);
 FRFD_CELL_MSZPTR_BASE w47bit (wb_d[47], wbrx, csw_d[47], cwrx, rdrx, rdD[47]);
 FRFD_CELL_MSZPTR_BASE w48bit (wb_d[48], wbrx, csw_d[48], cwrx, rdrx, rdD[48]);
 FRFD_CELL_MSZPTR_BASE w49bit (wb_d[49], wbrx, csw_d[49], cwrx, rdrx, rdD[49]);
//
 FRFD_CELL_MSZPTR_BASE w50bit (wb_d[50], wbrx, csw_d[50], cwrx, rdrx, rdD[50]);
 FRFD_CELL_MSZPTR_BASE w51bit (wb_d[51], wbrx, csw_d[51], cwrx, rdrx, rdD[51]);
 FRFD_CELL_MSZPTR_BASE w52bit (wb_d[52], wbrx, csw_d[52], cwrx, rdrx, rdD[52]);
 FRFD_CELL_MSZPTR_BASE w53bit (wb_d[53], wbrx, csw_d[53], cwrx, rdrx, rdD[53]);
 FRFD_CELL_MSZPTR_BASE w54bit (wb_d[54], wbrx, csw_d[54], cwrx, rdrx, rdD[54]);
 FRFD_CELL_MSZPTR_BASE w55bit (wb_d[55], wbrx, csw_d[55], cwrx, rdrx, rdD[55]);
 FRFD_CELL_MSZPTR_BASE w56bit (wb_d[56], wbrx, csw_d[56], cwrx, rdrx, rdD[56]);
 FRFD_CELL_MSZPTR_BASE w57bit (wb_d[57], wbrx, csw_d[57], cwrx, rdrx, rdD[57]);
 FRFD_CELL_MSZPTR_BASE w58bit (wb_d[58], wbrx, csw_d[58], cwrx, rdrx, rdD[58]);
 FRFD_CELL_MSZPTR_BASE w59bit (wb_d[59], wbrx, csw_d[59], cwrx, rdrx, rdD[59]);
//
 FRFD_CELL_MSZPTR_BASE w60bit (wb_d[60], wbrx, csw_d[60], cwrx, rdrx, rdD[60]);
 FRFD_CELL_MSZPTR_BASE w61bit (wb_d[61], wbrx, csw_d[61], cwrx, rdrx, rdD[61]);
 FRFD_CELL_MSZPTR_BASE w62bit (wb_d[62], wbrx, csw_d[62], cwrx, rdrx, rdD[62]);
 FRFD_CELL_MSZPTR_BASE w63bit (wb_d[63], wbrx, csw_d[63], cwrx, rdrx, rdD[63]);
			   

  endmodule




