/************************************************************************/
/************         IRR Datapath  - cell based            *************/
/************************************************************************/
/*									*/
/* Module Name:	 	CB_IRRDP                                    	*/
/* File Name:	 	cb_irrdp.v                            		*/
/* Function:		Cell based implementation of IRRDP  		*/
/*									*/
/* Language: 		Verilog						*/
/*									*/
/* Creator:		Andrew Chang  					*/
/* Creation date:	May 7, 1997			        	*/
/*									*/
/* History:								*/
/*		960507	achang	Created					*/
/*		970127	achang	Added CFG latch				*/
/*		970302	achang	Added explicit TINV_8 to iwbD_mp_v1	*/
/*				 due to loading  			*/
/*		970422  klayman removed thread 2.  Aliased thread 5->2  */
/*	                         in register file                       */
/*		971203	achang  Extended 2 bit path to 64bit 		*/
/*				 for use in thesis research 		*/
/*				Started adding back full IRRDP 		*/
/*				 functionality			        */
/*									*/
/* Copyright (C) 1994, 1995, 1996, 1997, 1998 Andrew Chang              */
/*                                                                      */
/* Massachusetts Institute of Technology                                */
/* Concurrent VLSI Architecture Group                                   */
/* All rights reserved                                                  */
/*									*/
/************************************************************************/

/* Interface


>>>>>>>>>>>>>>>> INPUT LIST <<<<<<<<<<<<<<<<<<<<<<<	
NOTE:	_1	static clk = HIGH
	_2	static clk = LOW
	_v1	valid by HIGH->LOW
	_v2	valid by LOW->HIGH
	_q1	qualified by  clk
	_q2	qualified by ~clk
	NONE	Static for complete cycle (ie DFF output)

*/

`include "/home/mm/rtl/map/clst/clst.vhout"

/*==>>*/
module CB_IRRDP
	( 
	 clk, 			// Note: clk_L not used in CB version

	 ld_irr_s1,
	 ld_irr_s2,

	 iwrx, mwrx,
         cwr2,cwr3,cwr4,cwr5,
         cwr6,cwr7, cwr8,cwr9,
   	 cwr10,cwr11,cwr12,cwr13,
         cwr14,cwr15,
  
         wbr2,wbr3,wbr4,wbr5,
         wbr6,  wbr7, wbr8,wbr9,	
	 wbr10,wbr11,wbr12,wbr13,
	 wbr14,wbr15,

	 sndrx,
	 sndflip, sndflip_L,

	 ir1rx, ir2rx,
	 mr1rx, mr2rx,

	 rdr2,rdr3,rdr4,rdr5,
    	 rdr6, rdr7, rdr8,rdr9,
	 rdr10,rdr11,rdr12,rdr13,
	 rdr14,rdr15,

	 ipLd, ipHld,
	 s1Iwb, s1Mwb, s1Fwb, s1Csw, s1Cswcc,  s1Gcc, s1Hld, 
	 s2Iwb, s2Mwb, s2Fwb, s2Csw, s2Cswcc,  s2Gcc, s2Hld, 
	 rrts_irr_s1, 
	 rrts_irr_s2, 
	 iprrts,	 

	 iip_1,
	 iwbD_v1, mwbD_v1, fwbCv_v1, cswD, cswCv,  gccv1_v1,
	 gccv2_v1,	 

  	 s1, s1cc, s1gcc, s1neg, s1pos, s1z, s1ip, 
   	 s2, s2cc, s2gcc, s2neg, s2pos, s2z, s2ip,
	 k,lccD1,lccD2, gccD1,gccD2,

	 selIfu, selCfg, 
	 cfg_ld, cfg_hld, cfg_csw, cfg_ts,

         mr1D, mr2D,    //     MSZ and PTR for MRR
         rrIP_1, rrS1_1, rrS2_1   // MSZ and PTR for S1 and S2
	);

  input clk;

  inout [`WORD_W-1:0] iwbD_v1;
  input [`WORD_W-1:0] mwbD_v1;
  input [`WORD_W-1:0] cswD;

  input [`IREGS-1:2] iwrx, mwrx;
  input [`VTHRDS-1:0] cwr2,cwr3,cwr4,cwr5;
  input [`VTHRDS-1:0] cwr6;
  input [`VTHRDS-2:0] cwr7, cwr8,cwr9;
  input [`VTHRDS-2:0] cwr10,cwr11,cwr12,cwr13;
  input [`VTHRDS-2:0] cwr14,cwr15;
  
  input [`VTHRDS-1:0] wbr2,wbr3,wbr4,wbr5;
  input [`VTHRDS-1:0] wbr6;
  input [`VTHRDS-2:0] wbr7, wbr8,wbr9;	
  input [`VTHRDS-2:0] wbr10,wbr11,wbr12,wbr13;
  input [`VTHRDS-2:0] wbr14,wbr15;

  input [`IREGS-1:2] sndrx;
  input [`IREGS-1:2] ir1rx, ir2rx;
  input [`IREGS-1:2] mr1rx, mr2rx;
  input [`VTHRDS-1:0] rdr2,rdr3,rdr4,rdr5;
  input [`VTHRDS-1:0] rdr6;
  input [`VTHRDS-2:0] rdr7, rdr8,rdr9;
  input [`VTHRDS-2:0] rdr10,rdr11,rdr12,rdr13;
  input [`VTHRDS-2:0] rdr14,rdr15;

  input [`VTHRDS-2:0] ipLd, ipHld;

  input s1cc, s1gcc, s1neg, s1pos, s1z, s1ip, s1;
  input s2cc, s2gcc, s2neg, s2pos, s2z, s2ip, s2;
  input [`iMM_L-1:0] k;
  input lccD1,lccD2, gccD1,gccD2;

  input [`VTHRDS-2:0]s1Hld, s1Iwb, s1Mwb, s1Fwb, s1Gcc;
  input [`VTHRDS-2:0]s1Csw, s1Cswcc ;
  input [`VTHRDS-2:0]s2Hld, s2Iwb, s2Mwb, s2Fwb, s2Gcc;
  input [`VTHRDS-2:0]s2Csw, s2Cswcc ;
  input [`VTHRDS-2:0]ld_irr_s1, ld_irr_s2;
  input [`VTHRDS-2:0]rrts_irr_s1, rrts_irr_s2 ;

  input [`VTHRDS-2:0] iprrts, gccv1_v1, gccv2_v1;
  input fwbCv_v1, cswCv;
  input [63:2] iip_1;

  input sndflip, sndflip_L;
  input selIfu, selCfg;
  input cfg_ld, cfg_hld, cfg_csw, cfg_ts;

  output [`WORD_W-1:0] mr1D, mr2D;
  output [63:2] rrIP_1;
  output [`WORD_W-1:0] rrS1_1, rrS2_1;

  wire [`WORD_W-3:0] sip_1, iip;
  wire [`WORD_W-1:0] ir1D, ir2D, lcfg_val;
  wire [`WORD_W-1:0] iwbD, mwbD_by, iwbD_wb;
  wire [`WORD_W-1:0] opr1, opr2;
  wire [`WORD_W-1:0] sendD;
  wire [`WORD_W-1:0] irrszd_s1_1, cfg_s1_1;
  wire [`VTHRDS-2:0] gccv1, gccv2;
  wire fwbCv;

/*****************************************************/
/******************* ASSIGNMENTS *********************/
/*****************************************************/

/******************* SEND FLIP  *********************/

assign #1
	iwbD_v1    = ( sndflip & ~sndflip_L) ?  iwbD       : `WORD_W'bz,
	iwbD       = iwbD_wb;

/******************* IWB BYPASS PLTCH *********************/

  PLTCH #(`WORD_W) IMPBYPltch (clk, ~iwbD_v1, iwbD_wb);



/******************* FWB BYPASS PLTCH *********************/

  PLTCH #1 FBYPltch (clk, ~fwbCv_v1, fwbCv);


/******************* GCC BYPASS PLTCH's *********************/

  PLTCH #(`VTHRDS-1) GCC1BYPltch (clk, gccv1_v1, gccv1);
  PLTCH #(`VTHRDS-1) GCC2BYPltch (clk, gccv2_v1, gccv2);



/******************* MWB BYPASS PLTCH *********************/

  PLTCH #(`WORD_W) MMPBYPltch (clk, ~mwbD_v1, mwbD_by);




/******************* IRFD **********************************/

  CB_IRFD cb_irfd
	(       
	  iwrx, 
	  cwr2,	 cwr3, cwr4, cwr5,		// Write Ports
	  cwr6,	 cwr7, cwr8, cwr9,		// 
	  cwr10, cwr11, cwr12, cwr13,		// 
	  cwr14, cwr15, 			// 

	  iwbD, mwbD_by, 		//	 Data
	  cswD, 

	  wbr2,	 wbr3, wbr4, wbr5,		// Local WB thread select 
	  wbr6,	 wbr7, wbr8, wbr9,		// 
	  wbr10, wbr11, wbr12, wbr13,		// 
	  wbr14, wbr15, 

	  sndrx,

	  ir1rx, ir2rx,				// Read Ports
	  mr1rx,mr2rx,
						
	  rdr2,	 rdr3, rdr4, rdr5,		// Read thread select  	
	  rdr6,	 rdr7, rdr8, rdr9,		// 
	  rdr10, rdr11, rdr12, rdr13,		// 
	  rdr14, rdr15, 


	  ir1D, ir2D,			// Read Data
	  mr1D, mr2D, 
	  sendD
	);

/******************* IP MUX ****************************/


CB_62B_MUX  IpMux (selIfu, selCfg,iip_1,`OPIP_W'b0,sip_1);


/******************* IP PLTCH ****************************/

PLTCH #(`WORD_W-2) IpPltch (clk, ~sip_1, iip);




  IMUXB mpmux
     ( 
       s1, s1cc, s1gcc, s1pos, s1neg, s1z, s1ip, 
       s2, s2cc, s2gcc, s2pos, s2neg, s2z, s2ip,			     
       k, {iip,2'b0}, 
       ir1D, ir2D,
       lccD1,lccD2, gccD1,gccD2,	
       opr1, opr2
     );



/******************* CFG LATCHES  *********************/


PLTCH #(`WORD_W)  mpcfgpl (clk, ~cswD, lcfg_val);

CB_OPSZNREG4_1   mpcfgnl 
        (clk, cfg_ld, 1'b0, 1'b0, cfg_csw, cfg_hld, 
       		 opr1, `WORD_W'b0, `WORD_W'b0, lcfg_val,
         cfg_ts,   
         cfg_s1_1);

  assign #1
      rrS1_1 = irrszd_s1_1 | cfg_s1_1;


/******************** OPSZD ****************************/

 wire nc0, nc1;

 CB_IRR_IOPSZD cb_opszd
	(
	 clk, 			// Note:  clk_L not needed
	 ld_irr_s1, 
	 ld_irr_s2, 
         ipLd, ipHld,
	 s1Iwb, s1Mwb, s1Fwb, s1Csw, s1Cswcc, s1Gcc, s1Hld, 
	 s2Iwb, s2Mwb, s2Fwb, s2Csw, s2Cswcc, s2Gcc, s2Hld,
	 rrts_irr_s1, 
	 rrts_irr_s2, 
	 iprrts,

	 {iip,2'b0},
	 opr1, iwbD, mwbD_by, fwbCv, cswD, cswCv, gccv1, 
	 opr2, gccv2,

	 {rrIP_1,nc0,nc1}, irrszd_s1_1, rrS2_1
	);
  


endmodule
