/************************************************************************/
/************         RR Stage OPSYNC Datapath Pipeline Registers   *****/
/************         for CELL_BASED IMPLEMENTATION		    *****/
/************************************************************************/
/*									*/
/* Module Name:	 	CB_IOPSZD                                  	*/
/* File Name:	 	cb_opszd.v	                     		*/
/* Function:		Behavioral Model of the OPSYNC Pipeline 	*/
/*			Registers forming the RR/SZ interface for:	*/
/*			IU	(derived from IOPSZD_MSZPTR	        */
/*									*/
/*			Includes bypass multiplexors.			*/
/*									*/
/* Language: 		Verilog						*/
/*									*/
/* Creator:		Andrew Chang  					*/
/*									*/
/* History:	971203  achang  Created 				*/
/*				Extended existing IOPSZD_MSZPTR		*/
/*				 width from 2 to 64			*/
/*				Also, extended input list and 		*/
/*				 functionality to match full IRRDP      */
/*				 implementation      			*/
/*									*/
/*									*/
/* Copyright (C) 1994, 1995, 1996, 1997, 1998 Andrew Chang              */
/*                                                                      */
/* Massachusetts Institute of Technology                                */
/* Concurrent VLSI Architecture Group                                   */
/* All rights reserved                                                  */
/*									*/
/************************************************************************/


//
//  Note: need to add back missing thread 971203
//
//



/*==>>*/
module CB_IOPSZD_BY				 // 
 	( clk, 
	  ld, iwb, mwb, fwb, csw, cswcc, gcc, hld, 
	  if_d, 				 // Input Path	
	  iwb_d, mwb_d, fwb_cv, csw_d, csw_cv, gcc_cv, // Bypass Pathes
	  rrts, 

	  rr_d 
	 );

	input clk;
	input [`VTHRDS-2:0] ld, iwb, mwb, fwb, csw, cswcc, gcc, hld, rrts;
	input [`WORD_W-1:0] if_d;
	input [`WORD_W-1:0] iwb_d, mwb_d, csw_d;	// Bypass Pathes
	input fwb_cv, csw_cv;
	input [`VTHRDS-2:0]  gcc_cv;

	inout [`WORD_W-1:0] rr_d;
/*<<==*/


  CB_OPSZNREG7_1  dhi0 	
      (clk, ld[0], iwb[0], mwb[0], csw[0], fwb[0],cswcc[0], gcc[0], hld[0], 
       if_d, iwb_d, mwb_d, 
       csw_d, fwb_cv, csw_cv, gcc_cv[0],
       rrts[0],rr_d);

  CB_OPSZNREG7_1  dhi1 	
      (clk, ld[1], iwb[1], mwb[1], csw[1], fwb[1], cswcc[1], gcc[1], hld[1], 
       if_d,iwb_d,mwb_d,
       csw_d, fwb_cv, csw_cv, gcc_cv[1],
       rrts[1],rr_d);

  CB_OPSZNREG7_1  dhi3 	
      (clk, ld[2], iwb[2], mwb[2], csw[2], fwb[2], cswcc[2], gcc[2], hld[2], 
       if_d,iwb_d,mwb_d, 
       csw_d,  fwb_cv, csw_cv, gcc_cv[2],
       rrts[2],rr_d);

  CB_OPSZNREG7_1  dhi4 	
      (clk, ld[3], iwb[3], mwb[3], csw[3], fwb[3], cswcc[3], gcc[3], hld[3], 
       if_d,iwb_d,mwb_d, 
       csw_d, fwb_cv, csw_cv, gcc_cv[3],
       rrts[3],rr_d);

  CB_OPSZNREG7_1  dhi5 	
      (clk, ld[4], iwb[4], mwb[4], csw[4], fwb[4], cswcc[4], gcc[4], hld[4], 
       if_d,iwb_d,mwb_d, 
       csw_d, fwb_cv, csw_cv, gcc_cv[4],
       rrts[4],rr_d);

endmodule


module CB_OPSZNREG4_1 (clk, l0, l1, l2, l3, hld, 
               di0, di1, di2, di3, sel, dout);
  input clk, l0, l1, l2, l3, hld;
  input [`WORD_W-1:0] di0, di1, di2, di3;
  input sel;
  inout [`WORD_W-1:0] dout ;

  wire sel_di;
  wire [`WORD_W-1:0] state, mux_di ;

  assign #1
      mux_di = l2 ? di2 : di3 ,
      sel_di = l2 | l3 ,
      dout = sel ? state : `WORD_W'bz;
//
  EMI_M4_NL mp_nl0 (clk, di0[0], di1[0], mux_di[0], l0, l1, sel_di, hld, state[0]);
  EMI_M4_NL mp_nl1 (clk, di0[1], di1[1], mux_di[1], l0, l1, sel_di, hld, state[1]);
  EMI_M4_NL mp_nl2 (clk, di0[2], di1[2], mux_di[2], l0, l1, sel_di, hld, state[2]);
  EMI_M4_NL mp_nl3 (clk, di0[3], di1[3], mux_di[3], l0, l1, sel_di, hld, state[3]);
  EMI_M4_NL mp_nl4 (clk, di0[4], di1[4], mux_di[4], l0, l1, sel_di, hld, state[4]);
  EMI_M4_NL mp_nl5 (clk, di0[5], di1[5], mux_di[5], l0, l1, sel_di, hld, state[5]);
  EMI_M4_NL mp_nl6 (clk, di0[6], di1[6], mux_di[6], l0, l1, sel_di, hld, state[6]);
  EMI_M4_NL mp_nl7 (clk, di0[7], di1[7], mux_di[7], l0, l1, sel_di, hld, state[7]);
  EMI_M4_NL mp_nl8 (clk, di0[8], di1[8], mux_di[8], l0, l1, sel_di, hld, state[8]);
  EMI_M4_NL mp_nl9 (clk, di0[9], di1[9], mux_di[9], l0, l1, sel_di, hld, state[9]);
//
  EMI_M4_NL mp_nl10 (clk, di0[10], di1[10], mux_di[10], l0, l1, sel_di, hld, state[10]);
  EMI_M4_NL mp_nl11 (clk, di0[11], di1[11], mux_di[11], l0, l1, sel_di, hld, state[11]);
  EMI_M4_NL mp_nl12 (clk, di0[12], di1[12], mux_di[12], l0, l1, sel_di, hld, state[12]);
  EMI_M4_NL mp_nl13 (clk, di0[13], di1[13], mux_di[13], l0, l1, sel_di, hld, state[13]);
  EMI_M4_NL mp_nl14 (clk, di0[14], di1[14], mux_di[14], l0, l1, sel_di, hld, state[14]);
  EMI_M4_NL mp_nl15 (clk, di0[15], di1[15], mux_di[15], l0, l1, sel_di, hld, state[15]);
  EMI_M4_NL mp_nl16 (clk, di0[16], di1[16], mux_di[16], l0, l1, sel_di, hld, state[16]);
  EMI_M4_NL mp_nl17 (clk, di0[17], di1[17], mux_di[17], l0, l1, sel_di, hld, state[17]);
  EMI_M4_NL mp_nl18 (clk, di0[18], di1[18], mux_di[18], l0, l1, sel_di, hld, state[18]);
  EMI_M4_NL mp_nl19 (clk, di0[19], di1[19], mux_di[19], l0, l1, sel_di, hld, state[19]);
//
  EMI_M4_NL mp_nl20 (clk, di0[20], di1[20], mux_di[20], l0, l1, sel_di, hld, state[20]);
  EMI_M4_NL mp_nl21 (clk, di0[21], di1[21], mux_di[21], l0, l1, sel_di, hld, state[21]);
  EMI_M4_NL mp_nl22 (clk, di0[22], di1[22], mux_di[22], l0, l1, sel_di, hld, state[22]);
  EMI_M4_NL mp_nl23 (clk, di0[23], di1[23], mux_di[23], l0, l1, sel_di, hld, state[23]);
  EMI_M4_NL mp_nl24 (clk, di0[24], di1[24], mux_di[24], l0, l1, sel_di, hld, state[24]);
  EMI_M4_NL mp_nl25 (clk, di0[25], di1[25], mux_di[25], l0, l1, sel_di, hld, state[25]);
  EMI_M4_NL mp_nl26 (clk, di0[26], di1[26], mux_di[26], l0, l1, sel_di, hld, state[26]);
  EMI_M4_NL mp_nl27 (clk, di0[27], di1[27], mux_di[27], l0, l1, sel_di, hld, state[27]);
  EMI_M4_NL mp_nl28 (clk, di0[28], di1[28], mux_di[28], l0, l1, sel_di, hld, state[28]);
  EMI_M4_NL mp_nl29 (clk, di0[29], di1[29], mux_di[29], l0, l1, sel_di, hld, state[29]);
//
  EMI_M4_NL mp_nl30 (clk, di0[30], di1[30], mux_di[30], l0, l1, sel_di, hld, state[30]);
  EMI_M4_NL mp_nl31 (clk, di0[31], di1[31], mux_di[31], l0, l1, sel_di, hld, state[31]);
  EMI_M4_NL mp_nl32 (clk, di0[32], di1[32], mux_di[32], l0, l1, sel_di, hld, state[32]);
  EMI_M4_NL mp_nl33 (clk, di0[33], di1[33], mux_di[33], l0, l1, sel_di, hld, state[33]);
  EMI_M4_NL mp_nl34 (clk, di0[34], di1[34], mux_di[34], l0, l1, sel_di, hld, state[34]);
  EMI_M4_NL mp_nl35 (clk, di0[35], di1[35], mux_di[35], l0, l1, sel_di, hld, state[35]);
  EMI_M4_NL mp_nl36 (clk, di0[36], di1[36], mux_di[36], l0, l1, sel_di, hld, state[36]);
  EMI_M4_NL mp_nl37 (clk, di0[37], di1[37], mux_di[37], l0, l1, sel_di, hld, state[37]);
  EMI_M4_NL mp_nl38 (clk, di0[38], di1[38], mux_di[38], l0, l1, sel_di, hld, state[38]);
  EMI_M4_NL mp_nl39 (clk, di0[39], di1[39], mux_di[39], l0, l1, sel_di, hld, state[39]);
//
  EMI_M4_NL mp_nl40 (clk, di0[40], di1[40], mux_di[40], l0, l1, sel_di, hld, state[40]);
  EMI_M4_NL mp_nl41 (clk, di0[41], di1[41], mux_di[41], l0, l1, sel_di, hld, state[41]);
  EMI_M4_NL mp_nl42 (clk, di0[42], di1[42], mux_di[42], l0, l1, sel_di, hld, state[42]);
  EMI_M4_NL mp_nl43 (clk, di0[43], di1[43], mux_di[43], l0, l1, sel_di, hld, state[43]);
  EMI_M4_NL mp_nl44 (clk, di0[44], di1[44], mux_di[44], l0, l1, sel_di, hld, state[44]);
  EMI_M4_NL mp_nl45 (clk, di0[45], di1[45], mux_di[45], l0, l1, sel_di, hld, state[45]);
  EMI_M4_NL mp_nl46 (clk, di0[46], di1[46], mux_di[46], l0, l1, sel_di, hld, state[46]);
  EMI_M4_NL mp_nl47 (clk, di0[47], di1[47], mux_di[47], l0, l1, sel_di, hld, state[47]);
  EMI_M4_NL mp_nl48 (clk, di0[48], di1[48], mux_di[48], l0, l1, sel_di, hld, state[48]);
  EMI_M4_NL mp_nl49 (clk, di0[49], di1[49], mux_di[49], l0, l1, sel_di, hld, state[49]);
//
  EMI_M4_NL mp_nl50 (clk, di0[50], di1[50], mux_di[50], l0, l1, sel_di, hld, state[50]);
  EMI_M4_NL mp_nl51 (clk, di0[51], di1[51], mux_di[51], l0, l1, sel_di, hld, state[51]);
  EMI_M4_NL mp_nl52 (clk, di0[52], di1[52], mux_di[52], l0, l1, sel_di, hld, state[52]);
  EMI_M4_NL mp_nl53 (clk, di0[53], di1[53], mux_di[53], l0, l1, sel_di, hld, state[53]);
  EMI_M4_NL mp_nl54 (clk, di0[54], di1[54], mux_di[54], l0, l1, sel_di, hld, state[54]);
  EMI_M4_NL mp_nl55 (clk, di0[55], di1[55], mux_di[55], l0, l1, sel_di, hld, state[55]);
  EMI_M4_NL mp_nl56 (clk, di0[56], di1[56], mux_di[56], l0, l1, sel_di, hld, state[56]);
  EMI_M4_NL mp_nl57 (clk, di0[57], di1[57], mux_di[57], l0, l1, sel_di, hld, state[57]);
  EMI_M4_NL mp_nl58 (clk, di0[58], di1[58], mux_di[58], l0, l1, sel_di, hld, state[58]);
  EMI_M4_NL mp_nl59 (clk, di0[59], di1[59], mux_di[59], l0, l1, sel_di, hld, state[59]);
//
  EMI_M4_NL mp_nl60 (clk, di0[60], di1[60], mux_di[60], l0, l1, sel_di, hld, state[60]);
  EMI_M4_NL mp_nl61 (clk, di0[61], di1[61], mux_di[61], l0, l1, sel_di, hld, state[61]);
  EMI_M4_NL mp_nl62 (clk, di0[62], di1[62], mux_di[62], l0, l1, sel_di, hld, state[62]);
  EMI_M4_NL mp_nl63 (clk, di0[63], di1[63], mux_di[63], l0, l1, sel_di, hld, state[63]);

endmodule



module CB_OPSZNREG7_1 (clk, l0, l1, l2, l3, l4, l5, l6, hld, 
               di0, di1, di2, di3, di4, di5, di6, sel, dout);
  input clk, l0, l1, l2, l3, l4, l5, l6, hld;
  input [`WORD_W-1:0] di0, di1, di2, di3;
  input di4, di5, di6;
  input sel;
  inout [`WORD_W-1:0] dout ;

  wire sel_di;
  wire [`WORD_W-1:0] state, mux_di ;

  assign #1
      mux_di = l2 ? di2 : 
	       l3 ? di3 :
	       l4 ? {`WORD_W-2'b0,di4} :
	       l5 ? {`WORD_W-2'b0,di5} :
	       l6 ? {`WORD_W-2'b0,di6} : `WORD_W'b0,
      sel_di = l2 | l3 | l4  | l5 | l6,
      dout = sel ? state : `WORD_W'bz;
//
  EMI_M4_NL mp_nl0 (clk, di0[0], di1[0], mux_di[0], l0, l1, sel_di, hld, state[0]);
  EMI_M4_NL mp_nl1 (clk, di0[1], di1[1], mux_di[1], l0, l1, sel_di, hld, state[1]);
  EMI_M4_NL mp_nl2 (clk, di0[2], di1[2], mux_di[2], l0, l1, sel_di, hld, state[2]);
  EMI_M4_NL mp_nl3 (clk, di0[3], di1[3], mux_di[3], l0, l1, sel_di, hld, state[3]);
  EMI_M4_NL mp_nl4 (clk, di0[4], di1[4], mux_di[4], l0, l1, sel_di, hld, state[4]);
  EMI_M4_NL mp_nl5 (clk, di0[5], di1[5], mux_di[5], l0, l1, sel_di, hld, state[5]);
  EMI_M4_NL mp_nl6 (clk, di0[6], di1[6], mux_di[6], l0, l1, sel_di, hld, state[6]);
  EMI_M4_NL mp_nl7 (clk, di0[7], di1[7], mux_di[7], l0, l1, sel_di, hld, state[7]);
  EMI_M4_NL mp_nl8 (clk, di0[8], di1[8], mux_di[8], l0, l1, sel_di, hld, state[8]);
  EMI_M4_NL mp_nl9 (clk, di0[9], di1[9], mux_di[9], l0, l1, sel_di, hld, state[9]);
//
  EMI_M4_NL mp_nl10 (clk, di0[10], di1[10], mux_di[10], l0, l1, sel_di, hld, state[10]);
  EMI_M4_NL mp_nl11 (clk, di0[11], di1[11], mux_di[11], l0, l1, sel_di, hld, state[11]);
  EMI_M4_NL mp_nl12 (clk, di0[12], di1[12], mux_di[12], l0, l1, sel_di, hld, state[12]);
  EMI_M4_NL mp_nl13 (clk, di0[13], di1[13], mux_di[13], l0, l1, sel_di, hld, state[13]);
  EMI_M4_NL mp_nl14 (clk, di0[14], di1[14], mux_di[14], l0, l1, sel_di, hld, state[14]);
  EMI_M4_NL mp_nl15 (clk, di0[15], di1[15], mux_di[15], l0, l1, sel_di, hld, state[15]);
  EMI_M4_NL mp_nl16 (clk, di0[16], di1[16], mux_di[16], l0, l1, sel_di, hld, state[16]);
  EMI_M4_NL mp_nl17 (clk, di0[17], di1[17], mux_di[17], l0, l1, sel_di, hld, state[17]);
  EMI_M4_NL mp_nl18 (clk, di0[18], di1[18], mux_di[18], l0, l1, sel_di, hld, state[18]);
  EMI_M4_NL mp_nl19 (clk, di0[19], di1[19], mux_di[19], l0, l1, sel_di, hld, state[19]);
//
  EMI_M4_NL mp_nl20 (clk, di0[20], di1[20], mux_di[20], l0, l1, sel_di, hld, state[20]);
  EMI_M4_NL mp_nl21 (clk, di0[21], di1[21], mux_di[21], l0, l1, sel_di, hld, state[21]);
  EMI_M4_NL mp_nl22 (clk, di0[22], di1[22], mux_di[22], l0, l1, sel_di, hld, state[22]);
  EMI_M4_NL mp_nl23 (clk, di0[23], di1[23], mux_di[23], l0, l1, sel_di, hld, state[23]);
  EMI_M4_NL mp_nl24 (clk, di0[24], di1[24], mux_di[24], l0, l1, sel_di, hld, state[24]);
  EMI_M4_NL mp_nl25 (clk, di0[25], di1[25], mux_di[25], l0, l1, sel_di, hld, state[25]);
  EMI_M4_NL mp_nl26 (clk, di0[26], di1[26], mux_di[26], l0, l1, sel_di, hld, state[26]);
  EMI_M4_NL mp_nl27 (clk, di0[27], di1[27], mux_di[27], l0, l1, sel_di, hld, state[27]);
  EMI_M4_NL mp_nl28 (clk, di0[28], di1[28], mux_di[28], l0, l1, sel_di, hld, state[28]);
  EMI_M4_NL mp_nl29 (clk, di0[29], di1[29], mux_di[29], l0, l1, sel_di, hld, state[29]);
//
  EMI_M4_NL mp_nl30 (clk, di0[30], di1[30], mux_di[30], l0, l1, sel_di, hld, state[30]);
  EMI_M4_NL mp_nl31 (clk, di0[31], di1[31], mux_di[31], l0, l1, sel_di, hld, state[31]);
  EMI_M4_NL mp_nl32 (clk, di0[32], di1[32], mux_di[32], l0, l1, sel_di, hld, state[32]);
  EMI_M4_NL mp_nl33 (clk, di0[33], di1[33], mux_di[33], l0, l1, sel_di, hld, state[33]);
  EMI_M4_NL mp_nl34 (clk, di0[34], di1[34], mux_di[34], l0, l1, sel_di, hld, state[34]);
  EMI_M4_NL mp_nl35 (clk, di0[35], di1[35], mux_di[35], l0, l1, sel_di, hld, state[35]);
  EMI_M4_NL mp_nl36 (clk, di0[36], di1[36], mux_di[36], l0, l1, sel_di, hld, state[36]);
  EMI_M4_NL mp_nl37 (clk, di0[37], di1[37], mux_di[37], l0, l1, sel_di, hld, state[37]);
  EMI_M4_NL mp_nl38 (clk, di0[38], di1[38], mux_di[38], l0, l1, sel_di, hld, state[38]);
  EMI_M4_NL mp_nl39 (clk, di0[39], di1[39], mux_di[39], l0, l1, sel_di, hld, state[39]);
//
  EMI_M4_NL mp_nl40 (clk, di0[40], di1[40], mux_di[40], l0, l1, sel_di, hld, state[40]);
  EMI_M4_NL mp_nl41 (clk, di0[41], di1[41], mux_di[41], l0, l1, sel_di, hld, state[41]);
  EMI_M4_NL mp_nl42 (clk, di0[42], di1[42], mux_di[42], l0, l1, sel_di, hld, state[42]);
  EMI_M4_NL mp_nl43 (clk, di0[43], di1[43], mux_di[43], l0, l1, sel_di, hld, state[43]);
  EMI_M4_NL mp_nl44 (clk, di0[44], di1[44], mux_di[44], l0, l1, sel_di, hld, state[44]);
  EMI_M4_NL mp_nl45 (clk, di0[45], di1[45], mux_di[45], l0, l1, sel_di, hld, state[45]);
  EMI_M4_NL mp_nl46 (clk, di0[46], di1[46], mux_di[46], l0, l1, sel_di, hld, state[46]);
  EMI_M4_NL mp_nl47 (clk, di0[47], di1[47], mux_di[47], l0, l1, sel_di, hld, state[47]);
  EMI_M4_NL mp_nl48 (clk, di0[48], di1[48], mux_di[48], l0, l1, sel_di, hld, state[48]);
  EMI_M4_NL mp_nl49 (clk, di0[49], di1[49], mux_di[49], l0, l1, sel_di, hld, state[49]);
//
  EMI_M4_NL mp_nl50 (clk, di0[50], di1[50], mux_di[50], l0, l1, sel_di, hld, state[50]);
  EMI_M4_NL mp_nl51 (clk, di0[51], di1[51], mux_di[51], l0, l1, sel_di, hld, state[51]);
  EMI_M4_NL mp_nl52 (clk, di0[52], di1[52], mux_di[52], l0, l1, sel_di, hld, state[52]);
  EMI_M4_NL mp_nl53 (clk, di0[53], di1[53], mux_di[53], l0, l1, sel_di, hld, state[53]);
  EMI_M4_NL mp_nl54 (clk, di0[54], di1[54], mux_di[54], l0, l1, sel_di, hld, state[54]);
  EMI_M4_NL mp_nl55 (clk, di0[55], di1[55], mux_di[55], l0, l1, sel_di, hld, state[55]);
  EMI_M4_NL mp_nl56 (clk, di0[56], di1[56], mux_di[56], l0, l1, sel_di, hld, state[56]);
  EMI_M4_NL mp_nl57 (clk, di0[57], di1[57], mux_di[57], l0, l1, sel_di, hld, state[57]);
  EMI_M4_NL mp_nl58 (clk, di0[58], di1[58], mux_di[58], l0, l1, sel_di, hld, state[58]);
  EMI_M4_NL mp_nl59 (clk, di0[59], di1[59], mux_di[59], l0, l1, sel_di, hld, state[59]);
//
  EMI_M4_NL mp_nl60 (clk, di0[60], di1[60], mux_di[60], l0, l1, sel_di, hld, state[60]);
  EMI_M4_NL mp_nl61 (clk, di0[61], di1[61], mux_di[61], l0, l1, sel_di, hld, state[61]);
  EMI_M4_NL mp_nl62 (clk, di0[62], di1[62], mux_di[62], l0, l1, sel_di, hld, state[62]);
  EMI_M4_NL mp_nl63 (clk, di0[63], di1[63], mux_di[63], l0, l1, sel_di, hld, state[63]);

endmodule



/*==>>*/
module CB_IRR_IOPSZD
	(
	 clk,
	 ld_irr_s1, 
	 ld_irr_s2, 
	 ip_ld, ip_hld,
	 s1_iwb, s1_mwb, s1_fwb, s1_csw, s1_cswcc, s1_gcc, s1_hld, 
	 s2_iwb, s2_mwb, s2_fwb, s2_csw, s2_cswcc, s2_gcc, s2_hld,
	 rrts_irr_s1, 
	 rrts_irr_s2, 
	 ip_rrts,

	 if_ip,
	 if_s1, iwb_d, mwb_d, fwb_cv, csw_d, csw_cv, gcc_cv1,
	 if_s2, gcc_cv2,

	 rr_ip, rr_s1, rr_s2	
	);

input clk;
input [`VTHRDS-2:0] ld_irr_s1, ld_irr_s2;
input [`VTHRDS-2:0] ip_ld, ip_hld;
input [`VTHRDS-2:0] s1_iwb, s1_mwb, s1_fwb, s1_csw, s1_cswcc, s1_gcc, s1_hld;
input [`VTHRDS-2:0] s2_iwb, s2_mwb, s2_fwb, s2_csw, s2_cswcc, s2_gcc, s2_hld;
input [`VTHRDS-2:0] rrts_irr_s1, rrts_irr_s2, ip_rrts, gcc_cv1, gcc_cv2;

input fwb_cv, csw_cv;
input [`WORD_W-1:0] if_ip;
input [`WORD_W-1:0] if_s1, if_s2, iwb_d, mwb_d, csw_d;
output [`WORD_W-1:0] rr_ip;
output [`WORD_W-1:0] rr_s1, rr_s2;
/*<<==*/


// Instantiations

/********************  SRC1 *********************/

  CB_IOPSZD_BY ip
     ( clk, ip_ld, 5'b0, 5'b0, 5'b0, 5'b0, 5'b0, 5'b0,
       ip_hld, 
       if_ip, `WORD_W'b0, `WORD_W'b0, 1'b0, `WORD_W'b0, 1'b0, 5'b0,
       ip_rrts, 	
       rr_ip  );



/********************  SRC1 *********************/

  CB_IOPSZD_BY s1
     ( clk, ld_irr_s1, s1_iwb, s1_mwb, s1_fwb, s1_csw, s1_cswcc, s1_gcc,
       s1_hld, 
       if_s1, iwb_d, mwb_d, fwb_cv, csw_d, csw_cv, gcc_cv1,
       rrts_irr_s1, rr_s1  );


/********************  SRC2 *********************/

  CB_IOPSZD_BY s2
     ( clk, ld_irr_s2, s2_iwb, s2_mwb, s2_fwb, s2_csw, s2_cswcc, s2_gcc,
       s2_hld, 
       if_s2, iwb_d, mwb_d, fwb_cv, csw_d, csw_cv, gcc_cv2,
       rrts_irr_s2, rr_s2  );

endmodule




